@@ -2,7 +2,7 @@ package WebService::ILS;
 
 use Modern::Perl;
 
-our $VERSION = "0.07";
+our $VERSION = "0.08";
 
 =encoding utf-8
 
@@ -701,7 +701,7 @@ sub process_json_response {
     }
 
     my $content_type = $response->header('Content-Type');
-    die $response->as_string
+    die "Invalid Content-Type\n".$response->as_string
         unless $content_type && $content_type =~ m!application/json!;
     my $content = $response->decoded_content
         or die $self->invalid_response_exception_string($response);
