@@ -44,7 +44,8 @@ sub with_delete_request {
 
     my $request = HTTP::Request::Common::DELETE( $url );
     my $response = $self->_request_with_auth($request);
-    return 1 if $response->is_success;
+    return $response->content ? $self->process_json_response($response, $callback) : 1
+      if $response->is_success;
 
     return $self->_error_result(
         sub { $self->process_json_error_response($response, $error_callback); },
