@@ -37,6 +37,7 @@ See L<WebService::ILS>
 use Carp;
 use HTTP::Request::Common;
 use URI::Escape;
+use Data::Dumper;
 
 use parent qw(WebService::ILS::JSON);
 
@@ -140,7 +141,7 @@ sub native_facets {
     my $self = shift;
 
     my $url = $self->api_url("/facets");
-    return $self->get_without_auth($url);
+    return $self->get_response($url);
 }
 
 
@@ -232,7 +233,7 @@ sub search {
     }
     if (my $page_number = delete $params->{page}) {
         die "page_size must be specified for paging" unless $params->{'page-size'};
-        $params->{'page-index'} = $page_number;
+        $params->{'page-index'} = $page_number - 1;
     }
     if (my $sort = delete $params->{sort}) {
         my $sa = $self->_parse_sort_string($sort, \%SORT_XLATE);
@@ -257,7 +258,7 @@ sub _search_result_xlate {
     return {
         items => [ map $self->_item_xlate($_->{item}), @{$res->{items} || []} ],
         page_size => $res->{pageSize},
-        page => $res->{pageIndex},
+        page => $res->{pageIndex} + 1,
         pages => $res->{pageCount},
     };
 }
@@ -267,7 +268,7 @@ my %SEARCH_RESULT_ITEM_XLATE = (
     title => "title",
     subtitle => "subtitle",
     description => "description",
-    media => "mediaType",
+    mediaType => "media",
     downloadUrl => "url",
     encryptionKey => "encryption_key",
     isbn => "isbn",
@@ -403,7 +404,7 @@ sub place_hold {
     my $res = $content_type && $content_type =~ m!application/json!
        ? eval { from_json( $content ) }
        : undef;
-    $res ||= $content; # response is rather useless
+    $res ||= {message => "Error response: $content"}; # response is rather useless
 
     my $holds = $self->holds(@_) or die "Cannot place hold, unkmown error";
     foreach my $i (@{ $holds->{items} }) {
@@ -412,7 +413,7 @@ sub place_hold {
             return $i;
         }
     }
-    die $res || "Cannot place hold, unkmown error";
+    die $res->{message} || "Cannot place hold, unknown error";
 }
 
 sub remove_hold {
@@ -424,7 +425,11 @@ sub remove_hold {
         \&_basic_callback,
         sub {
             my ($data) = @_;
-            die $data;
+            if (my $message = $data->{message}) {
+                return 1 if $message =~ m/not exists|expired/i;
+                die $message;
+            }
+            die Dumper($data);
         },
         $url
     );
@@ -482,7 +487,7 @@ sub checkout {
             return $i;
         }
     }
-    die $res->{messaage} || "Cannot checkout, unkmown error";
+    die $res->{message} || "Cannot checkout, unknown error";
 }
 
 sub renew {
@@ -509,12 +514,25 @@ sub return {
     my $self = shift;
     my $isbn = shift or croak "No isbn";
 
-    my $url = $self->circulation_action_url("/checkouts/$isbn", @_);
+    my $return_checkout;
+    my $checkouts = $self->checkouts(@_) or die "Cannot return, unknown error";
+    foreach my $i (@{ $checkouts->{items} }) {
+        if ($i->{isbn} eq $isbn) {
+            $return_checkout = 1;
+            last;
+        }
+    }
+
+    my $url = $self->circulation_action_url("/".($return_checkout ? "checkouts" : "holds")."/$isbn", @_);
     return $self->with_delete_request(
         \&_basic_callback,
         sub {
             my ($data) = @_;
-            die $data;
+            if (my $message = $data->{message}) {
+                return 1 if $message =~ m/not exists|expired/i;
+                die $message;
+            }
+            die Dumper($data);
         },
         $url
     );
