@@ -102,7 +102,7 @@ sub search {
         $params->{offset} = ($page_number - 1)*$page_size;
     }
     if (my $sort = delete $params->{sort}) {
-        $params->{sort} = $self->_build_sort_string($sort, \%SORT_XLATE);
+        $params->{sort} = join ",", @{ $self->_parse_sort_string($sort, \%SORT_XLATE) };
     }
     $params->{formats} = join ",", @{$params->{formats}} if ref $params->{formats};
 
@@ -138,7 +138,7 @@ my %SEARCH_RESULT_ITEM_XLATE = (
 );
 sub _item_xlate {
     my $self = shift;
-    my $item = $_;
+    my $item = shift;
 
     my $std_item = $self->_result_xlate($item, \%SEARCH_RESULT_ITEM_XLATE);
 
